@@ -5,7 +5,7 @@ from typing import List, Union
 from pathlib import Path
 
 
-__version__ = "2022.5.16.2"
+__version__ = "2022.5.16.3"
 log_format = logging.Formatter(
     "[%(asctime)s] %(filename)s/%(lineno)s/%(funcName)s/%(levelname)s: %(message)s"
 )
@@ -80,28 +80,54 @@ def configure_logger(
     if not append:
         clean_handler()
 
+    # 收集已有的 FileHandler 处理器输出文件路径列表
+    log_file_list = []
+    for handler in logger.handlers:
+        if isinstance(handler, logging.FileHandler):
+            log_file_list.append(str(handler.baseFilename))
+
     # 往日志句柄中添加处理器
     if handlers:
         for handler in handlers:
-            if isinstance(handler, logging.Handler):
-                handler.setLevel(level)
-                logger.addHandler(handler)
+            # 判断是否重复
+            if handler in logger.handlers:
+                logger.warning(f"日志处理器已经存在，忽略：{handler}")
+                continue
+
+            # StreamHandler 类型的处理器只保留一个
+            if type(handler) == logging.StreamHandler:
+                logger.warning(f"StreamHandler 类型处理器已经存在（控制台只保留一个），忽略：{handler}")
+                continue
+
+            # FileHandler 类型处理器不重复，输出到同一目的地的只保留一个
+            if isinstance(handler, logging.FileHandler):
+                if str(handler.baseFilename) in log_file_list:
+                    logger.warning(f"已经有一个相同目的地的处理器，忽略：{handler}")
+                    continue
+                else:
+                    handler.setLevel(level)
+                    logger.addHandler(handler)
+                    log_file_list.append(str(handler.baseFilename))
             else:
                 raise TypeError(f"类型错误，预期为{logging.Handler}类型，实际为{type(handler)}类型")
 
     if log_file:
-        log_file = Path(log_file)
-        if not log_file.parent.exists():
-            log_file.parent.mkdir(parents=True)
+        if str(log_file) in log_file_list:
+            logger.warning(f"已经有一个相同目的地的处理器，忽略：{log_file}")
+        else:
+            log_file = Path(log_file)
+            if not log_file.parent.exists():
+                log_file.parent.mkdir(parents=True)
 
-        file_handler = logging.handlers.TimedRotatingFileHandler(
-            log_file, when="D", backupCount=15, encoding="utf-8"
-        )
-        file_handler.setFormatter(log_format)
-        file_handler.setLevel(level)
-        logger.addHandler(file_handler)
+            file_handler = logging.handlers.TimedRotatingFileHandler(
+                log_file, when="D", backupCount=15, encoding="utf-8"
+            )
+            file_handler.setFormatter(log_format)
+            file_handler.setLevel(level)
+            logger.addHandler(file_handler)
+            log_file_list.append(str(log_file))
 
-    logger.debug("日志配置完成")
+    logger.debug(f"日志配置完成，当前日志处理器：{logger.handlers}")
 
 
-logger.debug(f"当前deng库版本号：{__version__}")
+logger.info(f"当前deng库版本号：{__version__}")
